ContactService class

Implemented types
Implementers

Constructors

ContactService(MethodChannel channel, EventChannel events, ContactMode mode)

Properties

channel → MethodChannel
final
contactEvents → Stream<ContactEvent?>
no setteroverride
defaultSort ↔ ContactSortOrder
getter/setter pair
events → EventChannel
final
hashCode → int
The hash code for this object.
no setterinherited
isAggregate → bool
no setter
mode → ContactMode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addContact(Contact contact) → Future<Contact>
Adds the contact to the device contact list - returns the saved contact, so you can access the identifier
override
configureLogs({Level? level, LoggingHandler? onLog}) → void
Configures logging. FlutterPhoneState uses the logging plugin.
override
deleteContact(Contact contact) → Future<bool>
Deletes the contact if it has a valid identifier
override
getContact(String identifier, {bool withThumbnails = true, bool withHiResPhoto = true, bool withUnifyInfo = true}) → Future<Contact?>
Retrieves a single contact by identifier
override
getContactImage(Object? identifier) → Future<Uint8List?>
override
getGroups() → Future<Iterable<Group>>
Updates the contact if it has a valid identifier
override
getTotalContacts({String? query, bool? phoneQuery}) → Future<int?>
override
listContacts({String? query, bool? phoneQuery, bool withThumbnails = true, bool withHiResPhoto = true, bool withUnifyInfo = false, int bufferSize = 20, ContactSortOrder? sortBy}) → PagingList<Contact>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openContactEditForm(dynamic identifier) → Future<Contact?>
Opens a native edit form for the contact with identifier. This can be a simple string, but you can also provide a ContactKeys instance
override
openContactInsertForm([Contact? data]) → Future<Contact?>
Opens a native insert form with data preloaded
override
streamContacts({String? query, bool? phoneQuery, bool withThumbnails = true, bool withHiResPhoto = true, bool withUnifyInfo = false, int bufferSize = 20, ContactSortOrder? sortBy}) → Stream<Contact>
Fetches all contacts, or when specified, the contacts with a name matching query. The stream terminates once the items are all iterated.
override
toString() → String
A string representation of this object.
inherited
updateContact(Contact contact) → Future<Contact>
Updates the contact if it has a valid identifier
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited