ContactDate class

Constructors

ContactDate({String? label, String? value, FlexiDate? date})
ContactDate.ofDate({String? label, required FlexiDate date})
ContactDate.ofValue({String? label, required String value, FlexiDate? date})

Properties

date → FlexiDate?
final
dateOrValue → String?
no setter
hashCode → int
The hash code for this object.
no setteroverride
label → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromMap(dynamic dyn) → ContactDate?