Item class

Item class used for contact fields which only have a label and a value, such as emails and phone numbers

Implementers
Available extensions

Constructors

Item({String? label, String? value})

Properties

equalsValue → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
label ↔ String?
getter/setter pair
props → List
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
value ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, String>?

Available on Item?, provided by the ItemToMap extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(dynamic dyn) → Item?