PhoneNumber class

Inheritance
Available extensions

Constructors

PhoneNumber({String? label, String? number})

Properties

equalsValue → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
label ↔ String?
getter/setter pairinherited
props → List
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
value ↔ String?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, String>?

Available on Item?, provided by the ItemToMap extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

sanitizer ← PhoneNumberSanitizer
no getter